#
# spec file for package python-maxminddb
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-maxminddb
Version:        2.6.3
Release:        1.1
Summary:        Reader for the MaxMind DB format
License:        Apache-2.0
URL:            http://www.maxmind.com/
Source:         https://files.pythonhosted.org/packages/source/m/maxminddb/maxminddb-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.6}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  libmaxminddb-devel
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This is a Python module for reading MaxMind DB files. The module includes both
a pure Python reader and an optional C extension.

MaxMind DB is a binary file format that stores data indexed by IP address
subnets (IPv4 or IPv6).

%prep
%setup -q -n maxminddb-%{version}
sed -i '/nose/d' setup.py

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/maxminddb/
%{python_sitearch}/maxminddb-%{version}*-info

%changelog
* Wed Apr 30 2025 Sebastian Wagner <sebix@sebix.at>
- update to version 2.6.3:
  - The vendored ``libmaxminddb`` has been updated to 1.12.0. This fixes a
  memory leak when opening a database fails.
  - Binary wheels are now built for Python 3.13.
- update to version 2.6.2:
  - The vendored ``libmaxminddb`` has been updated to 1.10.0. This fixes a
  bug that would cause incorrect results on databases that had search
  trees greater than 4 GB.
- update to version 2.6.1:
  - This release includes no source code changes. The only changes are to
  the release workflow.
  - Binary wheels are now built on Linux for aarch64. Pull request by Kevin
  Park. GitHub #160.
  - Binary wheels are now built on macOS for Apple silicon. Requested by
  Kevin Park. GitHub #152.
- update to version 2.6.0:
  - Added type annotations for instance variables on ``Metadata``
  - Updated type stubs for ``maxminddb.extension``.
  - ``setuptools`` is no longer listed as a runtime dependency. Pull request
  by Lewis Collard. GitHub #155.
- update to version 2.5.2:
  - The vendored ``libmaxminddb`` version was updated to 1.9.0. This fixes
  an issue when reading databases with a search tree exceeding 2 GB.
  Reported by Sami Salonen. GitHub #146.
- update to version 2.5.1:
  - This is a re-release of 2.5.0 to address missing files from the sdist.
  Reported by Lumír 'Frenzy' Balhar. GitHub #132.
- update to version 2.5.0:
  - IMPORTANT: Python 3.8 or greater is required. If you are using an older
  version, please use an earlier release.
  - Windows is now supported by the C extension.
  - The ``Reader`` class now implements the ``__iter__`` method. This will
  return an iterator that iterates over all records in the database,
  excluding repeated aliased of the IPv4 network. Requested by
  Jean-Baptiste Braun and others. GitHub #23.
  - The multiprocessing test now explicitly uses ``fork``. This allows it
  to run successfully on macOS. Pull request by Theodore Ni. GitHub #116.
  - A vendored copy of ``libmaxminddb`` will now be used by default when
  building the extension. If you wish to continue using the system shared
  library, you may set the ``MAXMINDDB_USE_SYSTEM_LIBMAXMINDDB`` environment
  variable to a true value when building the extension.
  - The C extension now builds on Python 3.13.
  - The C extension will now be built for PyPy.
* Tue Oct 17 2023 Markéta Machová <mmachova@suse.com>
- Update to 2.4.0
  * IMPORTANT: Python 3.7 or greater is required.
  * distutils is no longer used for building the C extension.
  * Missing Py_INCREF was added for the C extension.
  * The C extension now decrements the reference count on an object
    containing the database filename after its use in an error message
    rather than before.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Mon Mar 28 2022 pgajdos@suse.com
- python-mock is not required for build
* Fri Sep 24 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.2.0:
  - The return type for ``maxminddb.open_database()`` has been simplified
  to be just the ``Reader`` class as opposed to a union of that with
  the extension class. This is done by casting the extension to
  ``Reader``. The extension class has the same public API as the
  pure Python implementation. This simplifies type checking for users of
  this library. The ``Reader`` class is exposed as ``maxminddb.Reader``.
  Pull request by wouter bolsterlee. GitHub #88.
  - ``maxminddb.__all__`` is now set to define a public API. Pull request
  by wouter bolsterlee. GitHub #88.
  - Fix minor regression in ``repr`` output of ``maxminddb.reader.Metadata``
  in 2.1.0.
* Sat Sep 18 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.1.0:
  - The C extension now correctly supports objects that implement the
  ``os.PathLike`` interface.
  - When opening a database fails due to an access issue, the correct
  ``OSError`` subclass will now be thrown.
  - The ``Metadata`` class object is now available from the C extension
  module as ``maxminddb.extension.Metadata`` rather than
  ``maxminddb.extension.extension``.
  - Type stubs have been added for ``maxminddb.extension``.
* Sat Jun  5 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- disable python 2, fixes Leap builds. Python 2 is no longer supported.
  fixes boo#1186841
* Sun Nov  1 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.0.3:
  - The 2.0.0 release unintentionally required Python to be compiled with
    ``mmap`` support for the module to work. ``mmap`` is now optional
    again. Reported by john-heasman-cg. GitHub #76.
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Replace nose with pytest
* Tue Jul 28 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.0.2:
  - Added ``py.typed`` file per PEP 561. Reported by Árni Már Jónsson.
* Thu Jul 23 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.0.1:
  - Fix minimum required python version in ``setup.py``. Pull request by
  Boros Gábor. GitHub #69 & #70.
- update to version 2.0.0:
  - IMPORTANT: Python 3.6 or greater is required. If you are using an older
  version, please use a 1.x.x release.
  - Type hints have been added.
* Thu May  7 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.5.4:
  - 1.5.3 was missing a test database. This release adds the test file.
  There are no other changes. Reported by Lumír 'Frenzy' Balhar. GitHub #60.
- update to version 1.5.3:
  - Fix a segfault when decoding a database with a corrupt data section.
  Reported by Robert Scott. GitHub #58.
* Sat Mar 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Wed Jan  1 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.5.2:
  - Minor performance improvements in the pure Python reader.
* Sun Oct  6 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.5.1:
  - Fix a possible segfault due to not correctly incrementing the reference
    on a returned object.
- update to version 1.5.0:
  - Python 3.3 and 3.4 are no longer supported.
  - The extension source directory was moved to prevent an ``ImportWarning``
    when importing the module on Python 2 with ``-Wdefault`` set. Reported by
    David Szotten and Craig de Stigter. GitHub #31.
  - The ``get`` method now accepts ``ipaddress.IPv4Address`` and
    ``ipaddress.IPv6Address`` objects in addition to strings.  This works with
    both the pure Python implementation as well as the extension. Based on a
    pull request #48 by Eric Pruitt. GitHub #50.
  - A new method, ``get_with_prefix_len``, was added. This method returns a
    tuple containing the record and the prefix length.
* Wed Aug 29 2018 tchvatal@suse.com
- Update to 1.4.1:
  * Fixes for python 3.7
* Sun May 27 2018 sebix+novell.com@sebix.at
- update to version 1.4.0:
  * IMPORTANT: Previously, the pure Python reader would allow
  `ipaddress.IPv4Address` and `ipaddress.IPv6Address` objects when calling
  `.get()`. This would fail with the C extension. The fact that these objects
  worked at all was an implementation detail and has varied with different
  releases. This release makes the pure Python implementation consistent
  with the extension. A `TypeError` will now be thrown if you attempt to
  use these types with either the pure Python implementation or the
  extension. The IP address passed to `.get()` should be a string type.
  * Fix issue where incorrect size was used when unpacking some types with the
  pure Python reader. Reported by Lee Symes. GitHub #30.
  * You may now pass in the database via a file descriptor rather than a file
  name when creating a new ``maxminddb.Reader`` object using ``MODE_FD``.
  This will read the database from the file descriptor into memory. Pull
  request by nkinkade. GitHub #33.
* Thu May 25 2017 sebix+novell.com@sebix.at
- initial package
